@@ -1,8 +1,8 @@
 #ifndef _ISL_INCLUDE_ISL_STDINT_H
 #define _ISL_INCLUDE_ISL_STDINT_H 1
 #ifndef _GENERATED_STDINT_H
-#define _GENERATED_STDINT_H "isl 0.17.1"
-/* generated using gnu compiler gcc (nb2 20180327) 5.5.0 */
+#define _GENERATED_STDINT_H "isl 0.18"
+/* generated using gnu compiler OpenBSD clang version 11.1.0 */
 #define _STDINT_HAVE_STDINT_H 1
 #include <stdint.h>
 #endif
